# Lucide Icons Subpackage
from .hand_helping import HandHelping
from .underline import Underline
from .file_type_corner import FileTypeCorner
from .sigma import Sigma
from .clock_9 import Clock9
from .triangle_alert import TriangleAlert
from .ethernet_port import EthernetPort
from .triangle import Triangle
from .hand import Hand
from .search import Search
from .chart_scatter import ChartScatter
from .signpost_big import SignpostBig
from .volume_2 import Volume2
from .hand_heart import HandHeart
from .columns_3_cog import Columns3Cog
from .contact import Contact
from .beer_off import BeerOff
from .send_horizontal import SendHorizontal
from .move_down import MoveDown
from .clipboard_plus import ClipboardPlus
from .gamepad_2 import Gamepad2
from .lectern import Lectern
from .lasso import Lasso
from .eraser import Eraser
from .chart_line import ChartLine
from .disc_2 import Disc2
from .receipt import Receipt
from .bed_single import BedSingle
from .wine import Wine
from .briefcase_medical import BriefcaseMedical
from .ice_cream_bowl import IceCreamBowl
from .parking_meter import ParkingMeter
from .file_search import FileSearch
from .arrow_down import ArrowDown
from .check_line import CheckLine
from .figma import Figma
from .corner_right_up import CornerRightUp
from .file_key import FileKey
from .earth import Earth
from .laptop_minimal_check import LaptopMinimalCheck
from .chevrons_right import ChevronsRight
from .beef import Beef
from .flashlight import Flashlight
from .file_pen import FilePen
from .ghost import Ghost
from .monitor_cloud import MonitorCloud
from .list import List
from .biceps_flexed import BicepsFlexed
from .cctv import Cctv
from .volume_off import VolumeOff
from .text_cursor_input import TextCursorInput
from .image_upscale import ImageUpscale
from .megaphone import Megaphone
from .croissant import Croissant
from .toy_brick import ToyBrick
from .pencil_off import PencilOff
from .route_off import RouteOff
from .square_arrow_right import SquareArrowRight
from .briefcase_business import BriefcaseBusiness
from .house import House
from .swiss_franc import SwissFranc
from .navigation_2_off import Navigation2Off
from .bluetooth_off import BluetoothOff
from .bed import Bed
from .panel_right_close import PanelRightClose
from .signal_low import SignalLow
from .chevrons_down import ChevronsDown
from .memory_stick import MemoryStick
from .clock_arrow_down import ClockArrowDown
from .disc_3 import Disc3
from .wind import Wind
from .corner_up_right import CornerUpRight
from .clapperboard import Clapperboard
from .subscript import Subscript
from .file_digit import FileDigit
from .arrow_big_down_dash import ArrowBigDownDash
from .grape import Grape
from .flip_vertical import FlipVertical
from .hdmi_port import HdmiPort
from .target import Target
from .user_cog import UserCog
from .scissors import Scissors
from .minimize_2 import Minimize2
from .cog import Cog
from .waypoints import Waypoints
from .megaphone_off import MegaphoneOff
from .file_video_camera import FileVideoCamera
from .receipt_pound_sterling import ReceiptPoundSterling
from .crosshair import Crosshair
from .align_vertical_distribute_end import AlignVerticalDistributeEnd
from .pi import Pi
from .table_cells_merge import TableCellsMerge
from .square_equal import SquareEqual
from .file_sliders import FileSliders
from .package_open import PackageOpen
from .vegan import Vegan
from .airplay import Airplay
from .gallery_thumbnails import GalleryThumbnails
from .clock_8 import Clock8
from .section import Section
from .message_circle_warning import MessageCircleWarning
from .line_squiggle import LineSquiggle
from .badge_euro import BadgeEuro
from .repeat import Repeat
from .circle_user_round import CircleUserRound
from .square_chevron_right import SquareChevronRight
from .arrow_right_left import ArrowRightLeft
from .grip import Grip
from .luggage import Luggage
from .badge_turkish_lira import BadgeTurkishLira
from .hourglass import Hourglass
from .russian_ruble import RussianRuble
from .circle_chevron_right import CircleChevronRight
from .microwave import Microwave
from .volume_1 import Volume1
from .party_popper import PartyPopper
from .boxes import Boxes
from .file_heart import FileHeart
from .chess_rook import ChessRook
from .printer_check import PrinterCheck
from .reply import Reply
from .badge_percent import BadgePercent
from .type_outline import TypeOutline
from .square_dashed_kanban import SquareDashedKanban
from .hamburger import Hamburger
from .sunrise import Sunrise
from .toggle_right import ToggleRight
from .square_star import SquareStar
from .map_pin_plus_inside import MapPinPlusInside
from .bug_off import BugOff
from .message_square_share import MessageSquareShare
from .beer import Beer
from .pointer import Pointer
from .receipt_indian_rupee import ReceiptIndianRupee
from .chess_knight import ChessKnight
from .chart_bar_stacked import ChartBarStacked
from .squares_intersect import SquaresIntersect
from .sheet import Sheet
from .spray_can import SprayCan
from .scan_line import ScanLine
from .circle_check_big import CircleCheckBig
from .unfold_vertical import UnfoldVertical
from .chart_candlestick import ChartCandlestick
from .git_pull_request_draft import GitPullRequestDraft
from .chart_no_axes_column_increasing import ChartNoAxesColumnIncreasing
from .layout_list import LayoutList
from .umbrella import Umbrella
from .user import User
from .list_start import ListStart
from .file_chart_column_increasing import FileChartColumnIncreasing
from .lasso_select import LassoSelect
from .arrow_big_down import ArrowBigDown
from .iteration_cw import IterationCw
from .fullscreen import Fullscreen
from .message_circle_heart import MessageCircleHeart
from .sun_dim import SunDim
from .saudi_riyal import SaudiRiyal
from .chart_network import ChartNetwork
from .replace_all import ReplaceAll
from .square_arrow_out_down_left import SquareArrowOutDownLeft
from .cannabis import Cannabis
from .iteration_ccw import IterationCcw
from .message_circle_more import MessageCircleMore
from .file_minus import FileMinus
from .heart_plus import HeartPlus
from .square_power import SquarePower
from .square_chevron_up import SquareChevronUp
from .panda import Panda
from .align_horizontal_justify_start import AlignHorizontalJustifyStart
from .copy_plus import CopyPlus
from .timer_off import TimerOff
from .folder_check import FolderCheck
from .chart_column_decreasing import ChartColumnDecreasing
from .badge_japanese_yen import BadgeJapaneseYen
from .arrow_up_from_line import ArrowUpFromLine
from .flip_vertical_2 import FlipVertical2
from .annoyed import Annoyed
from .ligature import Ligature
from .message_square_warning import MessageSquareWarning
from .layout_grid import LayoutGrid
from .rocking_chair import RockingChair
from .chevrons_up_down import ChevronsUpDown
from .kayak import Kayak
from .badge_minus import BadgeMinus
from .calendar_off import CalendarOff
from .circle import Circle
from .air_vent import AirVent
from .phone_missed import PhoneMissed
from .text_align_center import TextAlignCenter
from .scale_3d import Scale3d
from .corner_left_up import CornerLeftUp
from .milk import Milk
from .clipboard_pen import ClipboardPen
from .file_up import FileUp
from .copyright import Copyright
from .picture_in_picture import PictureInPicture
from .vault import Vault
from .circle_power import CirclePower
from .omega import Omega
from .mailbox import Mailbox
from .gitlab import Gitlab
from .music import Music
from .rectangle_ellipsis import RectangleEllipsis
from .smartphone import Smartphone
from .file_symlink import FileSymlink
from .file_play import FilePlay
from .alarm_clock_check import AlarmClockCheck
from .handbag import Handbag
from .door_closed_locked import DoorClosedLocked
from .candy_off import CandyOff
from .turntable import Turntable
from .circuit_board import CircuitBoard
from .folder_tree import FolderTree
from .chart_gantt import ChartGantt
from .equal import Equal
from .grid_2x2_plus import Grid2x2Plus
from .recycle import Recycle
from .arrow_up_left import ArrowUpLeft
from .clipboard_type import ClipboardType
from .library import Library
from .panel_top_close import PanelTopClose
from .square_arrow_down import SquareArrowDown
from .list_plus import ListPlus
from .chevron_down import ChevronDown
from .backpack import Backpack
from .calendar_check_2 import CalendarCheck2
from .cloud_check import CloudCheck
from .heading import Heading
from .hexagon import Hexagon
from .non_binary import NonBinary
from .strikethrough import Strikethrough
from .calendar_fold import CalendarFold
from .message_square_heart import MessageSquareHeart
from .bird import Bird
from .bot_message_square import BotMessageSquare
from .sun_medium import SunMedium
from .calendar_arrow_down import CalendarArrowDown
from .badge_info import BadgeInfo
from .shield_plus import ShieldPlus
from .tickets import Tickets
from .book_marked import BookMarked
from .creative_commons import CreativeCommons
from .shirt import Shirt
from .dock import Dock
from .signpost import Signpost
from .door_closed import DoorClosed
from .github import Github
from .fold_horizontal import FoldHorizontal
from .nfc import Nfc
from .clipboard_paste import ClipboardPaste
from .cone import Cone
from .cooking_pot import CookingPot
from .proportions import Proportions
from .bring_to_front import BringToFront
from .usb import Usb
from .separator_vertical import SeparatorVertical
from .hard_hat import HardHat
from .cake_slice import CakeSlice
from .sun_moon import SunMoon
from .ticket import Ticket
from .calendar_plus_2 import CalendarPlus2
from .case_lower import CaseLower
from .mail_question_mark import MailQuestionMark
from .layout_template import LayoutTemplate
from .panel_right_open import PanelRightOpen
from .brackets import Brackets
from .star_off import StarOff
from .shrink import Shrink
from .shrimp import Shrimp
from .church import Church
from .circle_percent import CirclePercent
from .crop import Crop
from .flask_round import FlaskRound
from .brick_wall_fire import BrickWallFire
from .cookie import Cookie
from .chart_column_big import ChartColumnBig
from .redo_2 import Redo2
from .circle_slash_2 import CircleSlash2
from .calendar_1 import Calendar1
from .tag import Tag
from .book_check import BookCheck
from .octagon_pause import OctagonPause
from .cup_soda import CupSoda
from .option import Option
from .sparkle import Sparkle
from .briefcase import Briefcase
from .circle_chevron_down import CircleChevronDown
from .decimals_arrow_right import DecimalsArrowRight
from .presentation import Presentation
from .square_sigma import SquareSigma
from .rotate_cw import RotateCw
from .ellipsis_vertical import EllipsisVertical
from .badge_plus import BadgePlus
from .screen_share_off import ScreenShareOff
from .square_play import SquarePlay
from .align_horizontal_distribute_end import AlignHorizontalDistributeEnd
from .file_clock import FileClock
from .calendar_search import CalendarSearch
from .image_down import ImageDown
from .file_signal import FileSignal
from .swatch_book import SwatchBook
from .radius import Radius
from .folder_sync import FolderSync
from .panels_top_left import PanelsTopLeft
from .headset import Headset
from .circle_equal import CircleEqual
from .dessert import Dessert
from .carrot import Carrot
from .receipt_euro import ReceiptEuro
from .map import Map
from .check_check import CheckCheck
from .inbox import Inbox
from .clock_plus import ClockPlus
from .circle_alert import CircleAlert
from .tv_minimal import TvMinimal
from .power import Power
from .a_large_small import ALargeSmall
from .tent_tree import TentTree
from .database import Database
from .tickets_plane import TicketsPlane
from .captions import Captions
from .martini import Martini
from .arrow_up_to_line import ArrowUpToLine
from .monitor_down import MonitorDown
from .badge_indian_rupee import BadgeIndianRupee
from .camera_off import CameraOff
from .fuel import Fuel
from .satellite_dish import SatelliteDish
from .bike import Bike
from .decimals_arrow_left import DecimalsArrowLeft
from .chart_no_axes_column import ChartNoAxesColumn
from .swords import Swords
from .message_square_off import MessageSquareOff
from .scan_text import ScanText
from .arrow_down_z_a import ArrowDownZA
from .rat import Rat
from .tornado import Tornado
from .toggle_left import ToggleLeft
from .file import File
from .motorbike import Motorbike
from .puzzle import Puzzle
from .align_vertical_distribute_center import AlignVerticalDistributeCenter
from .receipt_turkish_lira import ReceiptTurkishLira
from .signal import Signal
from .egg_off import EggOff
from .arrow_up_1_0 import ArrowUp10
from .baseline import Baseline
from .vibrate_off import VibrateOff
from .glass_water import GlassWater
from .brain import Brain
from .files import Files
from .torus import Torus
from .scan_search import ScanSearch
from .helicopter import Helicopter
from .square_dashed_bottom_code import SquareDashedBottomCode
from .message_circle import MessageCircle
from .message_square_dot import MessageSquareDot
from .receipt_japanese_yen import ReceiptJapaneseYen
from .voicemail import Voicemail
from .octagon_minus import OctagonMinus
from .messages_square import MessagesSquare
from .ship_wheel import ShipWheel
from .message_square_quote import MessageSquareQuote
from .contrast import Contrast
from .cuboid import Cuboid
from .alarm_clock_plus import AlarmClockPlus
from .monitor_pause import MonitorPause
from .archive_x import ArchiveX
from .terminal import Terminal
from .move_diagonal import MoveDiagonal
from .droplet_off import DropletOff
from .file_scan import FileScan
from .arrow_up_wide_narrow import ArrowUpWideNarrow
from .banknote_arrow_down import BanknoteArrowDown
from .move import Move
from .maximize import Maximize
from .between_vertical_start import BetweenVerticalStart
from .laptop_minimal import LaptopMinimal
from .radar import Radar
from .logs import Logs
from .sparkles import Sparkles
from .lock_keyhole import LockKeyhole
from .octagon_x import OctagonX
from .scan_heart import ScanHeart
from .folder_root import FolderRoot
from .chevron_up import ChevronUp
from .square_percent import SquarePercent
from .haze import Haze
from .folder_output import FolderOutput
from .folder_symlink import FolderSymlink
from .vibrate import Vibrate
from .laugh import Laugh
from .clock_fading import ClockFading
from .scan_eye import ScanEye
from .spade import Spade
from .cloud_rain_wind import CloudRainWind
from .sliders_vertical import SlidersVertical
from .spline_pointer import SplinePointer
from .undo_2 import Undo2
from .step_back import StepBack
from .flask_conical_off import FlaskConicalOff
from .arrow_down_left import ArrowDownLeft
from .list_filter_plus import ListFilterPlus
from .file_text import FileText
from .file_stack import FileStack
from .folder_open import FolderOpen
from .package_minus import PackageMinus
from .droplet import Droplet
from .whole_word import WholeWord
from .paint_roller import PaintRoller
from .zap_off import ZapOff
from .clipboard_clock import ClipboardClock
from .square_kanban import SquareKanban
from .keyboard import Keyboard
from .x import X
from .chevrons_right_left import ChevronsRightLeft
from .joystick import Joystick
from .cigarette import Cigarette
from .bath import Bath
from .qr_code import QrCode
from .dot import Dot
from .file_search_corner import FileSearchCorner
from .ice_cream_cone import IceCreamCone
from .languages import Languages
from .ampersands import Ampersands
from .banknote_x import BanknoteX
from .amphora import Amphora
from .arrow_left_from_line import ArrowLeftFromLine
from .bell_minus import BellMinus
from .file_cog import FileCog
from .wheat import Wheat
from .eye_closed import EyeClosed
from .cable_car import CableCar
from .arrow_up_narrow_wide import ArrowUpNarrowWide
from .lock import Lock
from .dice_2 import Dice2
from .log_in import LogIn
from .squircle import Squircle
from .cloud_upload import CloudUpload
from .shield_ellipsis import ShieldEllipsis
from .ban import Ban
from .smartphone_nfc import SmartphoneNfc
from .list_video import ListVideo
from .text_select import TextSelect
from .shopping_bag import ShoppingBag
from .divide import Divide
from .piggy_bank import PiggyBank
from .battery_warning import BatteryWarning
from .wallet_minimal import WalletMinimal
from .circle_dollar_sign import CircleDollarSign
from .milk_off import MilkOff
from .rotate_ccw_key import RotateCcwKey
from .square_parking import SquareParking
from .refresh_ccw_dot import RefreshCcwDot
from .tally_2 import Tally2
from .shell import Shell
from .banknote_arrow_up import BanknoteArrowUp
from .repeat_2 import Repeat2
from .pilcrow import Pilcrow
from .circle_dot_dashed import CircleDotDashed
from .cloud_drizzle import CloudDrizzle
from .copy_minus import CopyMinus
from .spline import Spline
from .refresh_cw import RefreshCw
from .pen import Pen
from .user_pen import UserPen
from .rectangle_circle import RectangleCircle
from .plane import Plane
from .align_vertical_space_between import AlignVerticalSpaceBetween
from .chevron_right import ChevronRight
from .tally_3 import Tally3
from .clipboard import Clipboard
from .equal_not import EqualNot
from .package import Package
from .shield_user import ShieldUser
from .mars import Mars
from .instagram import Instagram
from .mail_warning import MailWarning
from .euro import Euro
from .link import Link
from .square_chevron_left import SquareChevronLeft
from .globe_lock import GlobeLock
from .dice_3 import Dice3
from .hand_platter import HandPlatter
from .video_off import VideoOff
from .user_round_plus import UserRoundPlus
from .gpu import Gpu
from .key import Key
from .square_activity import SquareActivity
from .shrub import Shrub
from .sailboat import Sailboat
from .square_slash import SquareSlash
from .brain_cog import BrainCog
from .meh import Meh
from .sliders_horizontal import SlidersHorizontal
from .door_open import DoorOpen
from .corner_down_right import CornerDownRight
from .beaker import Beaker
from .list_todo import ListTodo
from .cloud_sun import CloudSun
from .arrow_right import ArrowRight
from .store import Store
from .antenna import Antenna
from .chevron_first import ChevronFirst
from .wheat_off import WheatOff
from .aperture import Aperture
from .calendar_plus import CalendarPlus
from .brush import Brush
from .thermometer_snowflake import ThermometerSnowflake
from .clover import Clover
from .concierge_bell import ConciergeBell
from .log_out import LogOut
from .unfold_horizontal import UnfoldHorizontal
from .file_spreadsheet import FileSpreadsheet
from .square_radical import SquareRadical
from .circle_play import CirclePlay
from .square_arrow_up import SquareArrowUp
from .telescope import Telescope
from .ship import Ship
from .ear_off import EarOff
from .worm import Worm
from .wallpaper import Wallpaper
from .ambulance import Ambulance
from .space import Space
from .file_input import FileInput
from .book_dashed import BookDashed
from .list_indent_increase import ListIndentIncrease
from .hand_grab import HandGrab
from .stretch_vertical import StretchVertical
from .calendar_check import CalendarCheck
from .diff import Diff
from .shower_head import ShowerHead
from .square_pen import SquarePen
from .arrow_down_up import ArrowDownUp
from .git_pull_request import GitPullRequest
from .minimize import Minimize
from .group import Group
from .settings import Settings
from .cloud_snow import CloudSnow
from .notepad_text_dashed import NotepadTextDashed
from .calendar_x_2 import CalendarX2
from .cassette_tape import CassetteTape
from .thumbs_down import ThumbsDown
from .dice_1 import Dice1
from .move_down_left import MoveDownLeft
from .vote import Vote
from .house_heart import HouseHeart
from .bot_off import BotOff
from .type import Type
from .square_dashed_mouse_pointer import SquareDashedMousePointer
from .bow_arrow import BowArrow
from .square_menu import SquareMenu
from .mouse_pointer_click import MousePointerClick
from .regex import Regex
from .square_check_big import SquareCheckBig
from .badge_question_mark import BadgeQuestionMark
from .loader_circle import LoaderCircle
from .popsicle import Popsicle
from .lamp_floor import LampFloor
from .utensils import Utensils
from .map_pin_minus import MapPinMinus
from .rose import Rose
from .archive import Archive
from .bean import Bean
from .panels_right_bottom import PanelsRightBottom
from .equal_approximately import EqualApproximately
from .message_square_text import MessageSquareText
from .refresh_cw_off import RefreshCwOff
from .phone_outgoing import PhoneOutgoing
from .tally_1 import Tally1
from .arrow_up_from_dot import ArrowUpFromDot
from .candy import Candy
from .pocket import Pocket
from .repeat_1 import Repeat1
from .magnet import Magnet
from .circle_parking import CircleParking
from .mail import Mail
from .school import School
from .chart_spline import ChartSpline
from .arrow_big_right import ArrowBigRight
from .panel_top_bottom_dashed import PanelTopBottomDashed
from .shield import Shield
from .download import Download
from .kanban import Kanban
from .file_volume import FileVolume
from .expand import Expand
from .gallery_vertical_end import GalleryVerticalEnd
from .disc_album import DiscAlbum
from .pin import Pin
from .arrow_up_a_z import ArrowUpAZ
from .bandage import Bandage
from .square_check import SquareCheck
from .import_ import Import
from .webcam import Webcam
from .waves_arrow_up import WavesArrowUp
from .phone_forwarded import PhoneForwarded
from .bell_plus import BellPlus
from .square_dot import SquareDot
from .corner_right_down import CornerRightDown
from .square_divide import SquareDivide
from .book_open import BookOpen
from .forklift import Forklift
from .calendar_cog import CalendarCog
from .castle import Castle
from .orbit import Orbit
from .parentheses import Parentheses
from .projector import Projector
from .pilcrow_right import PilcrowRight
from .server import Server
from .user_round_check import UserRoundCheck
from .bolt import Bolt
from .tv import Tv
from .message_square_dashed import MessageSquareDashed
from .droplets import Droplets
from .skip_forward import SkipForward
from .archive_restore import ArchiveRestore
from .volume import Volume
from .lamp_wall_up import LampWallUp
from .drumstick import Drumstick
from .user_plus import UserPlus
from .wifi_zero import WifiZero
from .battery_medium import BatteryMedium
from .book_a import BookA
from .text_align_justify import TextAlignJustify
from .battery_charging import BatteryCharging
from .shapes import Shapes
from .solar_panel import SolarPanel
from .folders import Folders
from .satellite import Satellite
from .list_minus import ListMinus
from .circle_arrow_left import CircleArrowLeft
from .bookmark_minus import BookmarkMinus
from .list_chevrons_up_down import ListChevronsUpDown
from .heater import Heater
from .layers import Layers
from .earth_lock import EarthLock
from .spool import Spool
from .square_parking_off import SquareParkingOff
from .dna import Dna
from .mouse_off import MouseOff
from .slash import Slash
from .radio import Radio
from .align_center_vertical import AlignCenterVertical
from .alarm_clock import AlarmClock
from .alarm_clock_off import AlarmClockOff
from .book import Book
from .keyboard_music import KeyboardMusic
from .hotel import Hotel
from .book_text import BookText
from .variable import Variable
from .touchpad_off import TouchpadOff
from .bitcoin import Bitcoin
from .message_square_x import MessageSquareX
from .car_front import CarFront
from .alarm_smoke import AlarmSmoke
from .dice_4 import Dice4
from .skull import Skull
from .mail_minus import MailMinus
from .bot import Bot
from .plug import Plug
from .shield_x import ShieldX
from .train_track import TrainTrack
from .goal import Goal
from .square_chart_gantt import SquareChartGantt
from .file_chart_column import FileChartColumn
from .folder_archive import FolderArchive
from .signal_high import SignalHigh
from .user_minus import UserMinus
from .plane_landing import PlaneLanding
from .wallet import Wallet
from .circle_check import CircleCheck
from .tally_4 import Tally4
from .file_image import FileImage
from .square_dashed_bottom import SquareDashedBottom
from .panel_top_open import PanelTopOpen
from .bell import Bell
from .git_branch import GitBranch
from .square_m import SquareM
from .coffee import Coffee
from .funnel import Funnel
from .panel_left_dashed import PanelLeftDashed
from .code import Code
from .rail_symbol import RailSymbol
from .circle_divide import CircleDivide
from .cake import Cake
from .spell_check_2 import SpellCheck2
from .shredder import Shredder
from .user_lock import UserLock
from .settings_2 import Settings2
from .tally_5 import Tally5
from .chart_bar_decreasing import ChartBarDecreasing
from .message_circle_dashed import MessageCircleDashed
from .cloud_moon_rain import CloudMoonRain
from .radio_tower import RadioTower
from .thermometer import Thermometer
from .cast import Cast
from .milestone import Milestone
from .move_3d import Move3d
from .flag import Flag
from .podcast import Podcast
from .tv_minimal_play import TvMinimalPlay
from .git_fork import GitFork
from .eye_off import EyeOff
from .dice_5 import Dice5
from .tram_front import TramFront
from .battery import Battery
from .blinds import Blinds
from .chess_king import ChessKing
from .arrow_left_to_line import ArrowLeftToLine
from .newspaper import Newspaper
from .clipboard_pen_line import ClipboardPenLine
from .snowflake import Snowflake
from .disc import Disc
from .step_forward import StepForward
from .bomb import Bomb
from .piano import Piano
from .book_copy import BookCopy
from .map_pin_plus import MapPinPlus
from .arrow_up_0_1 import ArrowUp01
from .database_zap import DatabaseZap
from .git_branch_minus import GitBranchMinus
from .rotate_3d import Rotate3d
from .star_half import StarHalf
from .switch_camera import SwitchCamera
from .image_plus import ImagePlus
from .square_round_corner import SquareRoundCorner
from .pencil_ruler import PencilRuler
from .container import Container
from .ruler import Ruler
from .turtle import Turtle
from .frown import Frown
from .tree_pine import TreePine
from .audio_lines import AudioLines
from .circle_slash import CircleSlash
from .notebook_text import NotebookText
from .layout_dashboard import LayoutDashboard
from .cpu import Cpu
from .align_end_horizontal import AlignEndHorizontal
from .flame_kindling import FlameKindling
from .cloud_alert import CloudAlert
from .clipboard_list import ClipboardList
from .biohazard import Biohazard
from .folder_x import FolderX
from .book_open_check import BookOpenCheck
from .list_ordered import ListOrdered
from .factory import Factory
from .bold import Bold
from .tablets import Tablets
from .wifi_low import WifiLow
from .fence import Fence
from .trophy import Trophy
from .scan_qr_code import ScanQrCode
from .hash import Hash
from .shield_minus import ShieldMinus
from .link_2_off import Link2Off
from .dam import Dam
from .share_2 import Share2
from .battery_full import BatteryFull
from .plus import Plus
from .monitor_stop import MonitorStop
from .panel_bottom import PanelBottom
from .clipboard_minus import ClipboardMinus
from .check import Check
from .align_vertical_justify_end import AlignVerticalJustifyEnd
from .map_minus import MapMinus
from .rabbit import Rabbit
from .plug_zap import PlugZap
from .nut import Nut
from .mail_plus import MailPlus
from .move_down_right import MoveDownRight
from .rotate_ccw import RotateCcw
from .circle_star import CircleStar
from .heart_crack import HeartCrack
from .flip_horizontal_2 import FlipHorizontal2
from .hard_drive import HardDrive
from .between_horizontal_end import BetweenHorizontalEnd
from .tent import Tent
from .trending_up_down import TrendingUpDown
from .hard_drive_download import HardDriveDownload
from .circle_fading_plus import CircleFadingPlus
from .pen_line import PenLine
from .align_vertical_space_around import AlignVerticalSpaceAround
from .hospital import Hospital
from .case_sensitive import CaseSensitive
from .focus import Focus
from .bluetooth import Bluetooth
from .align_end_vertical import AlignEndVertical
from .square_split_vertical import SquareSplitVertical
from .headphones import Headphones
from .map_pin_x import MapPinX
from .table_properties import TableProperties
from .git_pull_request_create_arrow import GitPullRequestCreateArrow
from .folder_git_2 import FolderGit2
from .book_alert import BookAlert
from .square_x import SquareX
from .square_asterisk import SquareAsterisk
from .rss import Rss
from .table_cells_split import TableCellsSplit
from .flower_2 import Flower2
from .landmark import Landmark
from .wifi import Wifi
from .corner_up_left import CornerUpLeft
from .file_archive import FileArchive
from .square_arrow_up_left import SquareArrowUpLeft
from .arrow_down_from_line import ArrowDownFromLine
from .watch import Watch
from .square_arrow_down_right import SquareArrowDownRight
from .scale import Scale
from .dice_6 import Dice6
from .message_square_more import MessageSquareMore
from .ampersand import Ampersand
from .dna_off import DnaOff
from .square_arrow_out_up_right import SquareArrowOutUpRight
from .hand_coins import HandCoins
from .roller_coaster import RollerCoaster
from .monitor_smartphone import MonitorSmartphone
from .venus import Venus
from .list_indent_decrease import ListIndentDecrease
from .git_commit_vertical import GitCommitVertical
from .soap_dispenser_droplet import SoapDispenserDroplet
from .info import Info
from .blocks import Blocks
from .popcorn import Popcorn
from .file_badge import FileBadge
from .badge_dollar_sign import BadgeDollarSign
from .user_x import UserX
from .navigation_off import NavigationOff
from .key_square import KeySquare
from .ticket_minus import TicketMinus
from .dog import Dog
from .layout_panel_left import LayoutPanelLeft
from .fan import Fan
from .radio_receiver import RadioReceiver
from .loader import Loader
from .palette import Palette
from .pilcrow_left import PilcrowLeft
from .file_x_corner import FileXCorner
from .diamond_plus import DiamondPlus
from .circle_arrow_out_down_left import CircleArrowOutDownLeft
from .receipt_swiss_franc import ReceiptSwissFranc
from .package_2 import Package2
from .chart_no_axes_combined import ChartNoAxesCombined
from .file_plus_corner import FilePlusCorner
from .funnel_x import FunnelX
from .case_upper import CaseUpper
from .volleyball import Volleyball
from .id_card_lanyard import IdCardLanyard
from .refresh_ccw import RefreshCcw
from .cloud_fog import CloudFog
from .git_branch_plus import GitBranchPlus
from .file_x import FileX
from .heading_1 import Heading1
from .hop import Hop
from .folder_up import FolderUp
from .soup import Soup
from .folder_plus import FolderPlus
from .badge_russian_ruble import BadgeRussianRuble
from .git_merge import GitMerge
from .japanese_yen import JapaneseYen
from .grip_horizontal import GripHorizontal
from .list_x import ListX
from .shield_half import ShieldHalf
from .mic import Mic
from .venetian_mask import VenetianMask
from .rainbow import Rainbow
from .git_pull_request_arrow import GitPullRequestArrow
from .copy import Copy
from .smile_plus import SmilePlus
from .fish import Fish
from .move_up_left import MoveUpLeft
from .card_sim import CardSim
from .list_tree import ListTree
from .zoom_in import ZoomIn
from .circle_chevron_up import CircleChevronUp
from .circle_arrow_out_down_right import CircleArrowOutDownRight
from .search_check import SearchCheck
from .signature import Signature
from .arrow_down_to_line import ArrowDownToLine
from .battery_plus import BatteryPlus
from .glasses import Glasses
from .coins import Coins
from .align_start_vertical import AlignStartVertical
from .arrows_up_from_line import ArrowsUpFromLine
from .user_star import UserStar
from .snail import Snail
from .library_big import LibraryBig
from .bookmark_x import BookmarkX
from .book_key import BookKey
from .panel_left import PanelLeft
from .test_tube_diagonal import TestTubeDiagonal
from .origami import Origami
from .square_library import SquareLibrary
from .message_circle_off import MessageCircleOff
from .square_user_round import SquareUserRound
from .wand_sparkles import WandSparkles
from .text_quote import TextQuote
from .caravan import Caravan
from .badge_cent import BadgeCent
from .panel_top_dashed import PanelTopDashed
from .notebook_tabs import NotebookTabs
from .test_tubes import TestTubes
from .fire_extinguisher import FireExtinguisher
from .egg_fried import EggFried
from .flag_triangle_left import FlagTriangleLeft
from .text_cursor import TextCursor
from .image import Image
from .file_question_mark import FileQuestionMark
from .panel_bottom_open import PanelBottomOpen
from .maximize_2 import Maximize2
from .vector_square import VectorSquare
from .lightbulb import Lightbulb
from .server_off import ServerOff
from .arrow_big_left_dash import ArrowBigLeftDash
from .image_play import ImagePlay
from .sunset import Sunset
from .save import Save
from .smile import Smile
from .search_code import SearchCode
from .lamp import Lamp
from .siren import Siren
from .images import Images
from .scan import Scan
from .navigation import Navigation
from .circle_pound_sterling import CirclePoundSterling
from .cloud_lightning import CloudLightning
from .turkish_lira import TurkishLira
from .user_round_pen import UserRoundPen
from .square_dashed_top_solid import SquareDashedTopSolid
from .citrus import Citrus
from .message_square_diff import MessageSquareDiff
from .bell_electric import BellElectric
from .ham import Ham
from .square_square import SquareSquare
from .monitor_play import MonitorPlay
from .barrel import Barrel
from .badge_pound_sterling import BadgePoundSterling
from .hard_drive_upload import HardDriveUpload
from .app_window import AppWindow
from .badge import Badge
from .theater import Theater
from .paperclip import Paperclip
from .wifi_sync import WifiSync
from .heading_2 import Heading2
from .clock_check import ClockCheck
from .square_scissors import SquareScissors
from .fast_forward import FastForward
from .flag_triangle_right import FlagTriangleRight
from .calendar_range import CalendarRange
from .contact_round import ContactRound
from .syringe import Syringe
from .spotlight import Spotlight
from .search_slash import SearchSlash
from .sticker import Sticker
from .award import Award
from .panel_right_dashed import PanelRightDashed
from .squares_exclude import SquaresExclude
from .zoom_out import ZoomOut
from .square_arrow_out_up_left import SquareArrowOutUpLeft
from .box import Box
from .thumbs_up import ThumbsUp
from .superscript import Superscript
from .ticket_percent import TicketPercent
from .battery_low import BatteryLow
from .touchpad import Touchpad
from .speech import Speech
from .percent import Percent
from .square_chevron_down import SquareChevronDown
from .square import Square
from .crown import Crown
from .bluetooth_searching import BluetoothSearching
from .timer_reset import TimerReset
from .stethoscope import Stethoscope
from .eclipse import Eclipse
from .donut import Donut
from .candy_cane import CandyCane
from .play import Play
from .folder_heart import FolderHeart
from .pen_off import PenOff
from .file_check import FileCheck
from .leafy_green import LeafyGreen
from .circle_small import CircleSmall
from .tangent import Tangent
from .book_audio import BookAudio
from .table import Table
from .split import Split
from .send import Send
from .barcode import Barcode
from .file_headphone import FileHeadphone
from .videotape import Videotape
from .scooter import Scooter
from .scroll import Scroll
from .phone_call import PhoneCall
from .columns_4 import Columns4
from .rectangle_goggles import RectangleGoggles
from .baggage_claim import BaggageClaim
from .message_square_lock import MessageSquareLock
from .circle_arrow_out_up_right import CircleArrowOutUpRight
from .radiation import Radiation
from .speaker import Speaker
from .user_round_search import UserRoundSearch
from .undo_dot import UndoDot
from .facebook import Facebook
from .codesandbox import Codesandbox
from .file_down import FileDown
from .badge_check import BadgeCheck
from .baby import Baby
from .smartphone_charging import SmartphoneCharging
from .book_plus import BookPlus
from .unplug import Unplug
from .heading_3 import Heading3
from .circle_question_mark import CircleQuestionMark
from .folder_code import FolderCode
from .bluetooth_connected import BluetoothConnected
from .table_of_contents import TableOfContents
from .camera import Camera
from .link_2 import Link2
from .printer import Printer
from .list_collapse import ListCollapse
from .workflow import Workflow
from .trees import Trees
from .panel_left_close import PanelLeftClose
from .git_graph import GitGraph
from .redo import Redo
from .captions_off import CaptionsOff
from .club import Club
from .folder_minus import FolderMinus
from .move_diagonal_2 import MoveDiagonal2
from .combine import Combine
from .arrow_up_right import ArrowUpRight
from .truck import Truck
from .layout_panel_top import LayoutPanelTop
from .book_search import BookSearch
from .life_buoy import LifeBuoy
from .user_search import UserSearch
from .square_user import SquareUser
from .table_columns_split import TableColumnsSplit
from .between_horizontal_start import BetweenHorizontalStart
from .pickaxe import Pickaxe
from .map_pin_x_inside import MapPinXInside
from .package_x import PackageX
from .pen_tool import PenTool
from .alarm_clock_minus import AlarmClockMinus
from .panels_left_bottom import PanelsLeftBottom
from .circle_gauge import CircleGauge
from .folder_cog import FolderCog
from .at_sign import AtSign
from .rotate_ccw_square import RotateCcwSquare
from .text_align_end import TextAlignEnd
from .map_pin_pen import MapPinPen
from .circle_arrow_right import CircleArrowRight
from .shield_alert import ShieldAlert
from .map_pin_off import MapPinOff
from .list_restart import ListRestart
from .house_wifi import HouseWifi
from .hand_metal import HandMetal
from .egg import Egg
from .car_taxi_front import CarTaxiFront
from .square_mouse_pointer import SquareMousePointer
from .hand_fist import HandFist
from .brick_wall_shield import BrickWallShield
from .monitor_x import MonitorX
from .square_terminal import SquareTerminal
from .grid_2x2_check import Grid2x2Check
from .hat_glasses import HatGlasses
from .bus import Bus
from .file_pen_line import FilePenLine
from .book_heart import BookHeart
from .infinity import Infinity
from .gem import Gem
from .git_compare import GitCompare
from .receipt_cent import ReceiptCent
from .feather import Feather
from .webhook_off import WebhookOff
from .trash import Trash
from .monitor_cog import MonitorCog
from .squares_subtract import SquaresSubtract
from .tree_palm import TreePalm
from .chart_bar import ChartBar
from .arrow_down_1_0 import ArrowDown10
from .database_backup import DatabaseBackup
from .bubbles import Bubbles
from .armchair import Armchair
from .wifi_off import WifiOff
from .truck_electric import TruckElectric
from .transgender import Transgender
from .user_round import UserRound
from .ungroup import Ungroup
from .toilet import Toilet
from .book_lock import BookLock
from .leaf import Leaf
from .arrow_down_wide_narrow import ArrowDownWideNarrow
from .network import Network
from .app_window_mac import AppWindowMac
from .arrow_up_z_a import ArrowUpZA
from .scan_barcode import ScanBarcode
from .house_plus import HousePlus
from .corner_left_down import CornerLeftDown
from .map_pin_minus_inside import MapPinMinusInside
from .message_square_plus import MessageSquarePlus
from .folder_clock import FolderClock
from .map_pin_house import MapPinHouse
from .paintbrush_vertical import PaintbrushVertical
from .dollar_sign import DollarSign
from .triangle_right import TriangleRight
from .indian_rupee import IndianRupee
from .construction import Construction
from .circle_plus import CirclePlus
from .graduation_cap import GraduationCap
from .scan_face import ScanFace
from .fish_symbol import FishSymbol
from .monitor_speaker import MonitorSpeaker
from .guitar import Guitar
from .form import Form
from .star import Star
from .lock_keyhole_open import LockKeyholeOpen
from .monitor_check import MonitorCheck
from .sandwich import Sandwich
from .chef_hat import ChefHat
from .wifi_pen import WifiPen
from .heading_6 import Heading6
from .cloud_off import CloudOff
from .save_all import SaveAll
from .file_user import FileUser
from .sun import Sun
from .wrench import Wrench
from .signal_medium import SignalMedium
from .pyramid import Pyramid
from .book_minus import BookMinus
from .gauge import Gauge
from .chart_column import ChartColumn
from .message_square import MessageSquare
from .bug_play import BugPlay
from .book_x import BookX
from .heading_4 import Heading4
from .chart_column_increasing import ChartColumnIncreasing
from .pizza import Pizza
from .unlink import Unlink
from .philippine_peso import PhilippinePeso
from .chevrons_down_up import ChevronsDownUp
from .bone import Bone
from .flashlight_off import FlashlightOff
from .grid_3x2 import Grid3x2
from .anchor import Anchor
from .hammer import Hammer
from .chevrons_left_right_ellipsis import ChevronsLeftRightEllipsis
from .file_braces_corner import FileBracesCorner
from .plug_2 import Plug2
from .notebook_pen import NotebookPen
from .chevrons_up import ChevronsUp
from .columns_3 import Columns3
from .move_horizontal import MoveHorizontal
from .highlighter import Highlighter
from .square_arrow_up_right import SquareArrowUpRight
from .tablet_smartphone import TabletSmartphone
from .circle_stop import CircleStop
from .twitch import Twitch
from .chart_no_axes_column_decreasing import ChartNoAxesColumnDecreasing
from .chart_pie import ChartPie
from .banana import Banana
from .tree_deciduous import TreeDeciduous
from .folder_lock import FolderLock
from .locate import Locate
from .list_music import ListMusic
from .bug import Bug
from .panel_top import PanelTop
from .message_square_code import MessageSquareCode
from .mail_open import MailOpen
from .youtube import Youtube
from .file_chart_line import FileChartLine
from .shield_question_mark import ShieldQuestionMark
from .chevrons_left_right import ChevronsLeftRight
from .bookmark_plus import BookmarkPlus
from .a_arrow_up import AArrowUp
from .file_code_corner import FileCodeCorner
from .tower_control import TowerControl
from .book_up import BookUp
from .pocket_knife import PocketKnife
from .shovel import Shovel
from .compass import Compass
from .file_minus_corner import FileMinusCorner
from .align_horizontal_justify_end import AlignHorizontalJustifyEnd
from .server_crash import ServerCrash
from .traffic_cone import TrafficCone
from .triangle_dashed import TriangleDashed
from .plane_takeoff import PlaneTakeoff
from .house_plug import HousePlug
from .folder_kanban import FolderKanban
from .mail_search import MailSearch
from .image_up import ImageUp
from .cloud_moon import CloudMoon
from .waves_arrow_down import WavesArrowDown
from .columns_2 import Columns2
from .warehouse import Warehouse
from .calendar_arrow_up import CalendarArrowUp
from .rotate_cw_square import RotateCwSquare
from .square_function import SquareFunction
from .frame import Frame
from .credit_card import CreditCard
from .circle_arrow_down import CircleArrowDown
from .calendars import Calendars
from .table_2 import Table2
from .copyleft import Copyleft
from .grid_3x3 import Grid3x3
from .message_circle_question_mark import MessageCircleQuestionMark
from .ticket_x import TicketX
from .align_vertical_justify_start import AlignVerticalJustifyStart
from .heart_off import HeartOff
from .cylinder import Cylinder
from .computer import Computer
from .book_type import BookType
from .pill_bottle import PillBottle
from .heading_5 import Heading5
from .thermometer_sun import ThermometerSun
from .locate_off import LocateOff
from .reply_all import ReplyAll
from .pencil import Pencil
from .cloud_rain import CloudRain
from .mars_stroke import MarsStroke
from .send_to_back import SendToBack
from .git_pull_request_closed import GitPullRequestClosed
from .arrow_big_right_dash import ArrowBigRightDash
from .wind_arrow_down import WindArrowDown
from .align_vertical_distribute_start import AlignVerticalDistributeStart
from .book_down import BookDown
from .pound_sterling import PoundSterling
from .monitor_up import MonitorUp
from .mouse_pointer_2_off import MousePointer2Off
from .bean_off import BeanOff
from .trash_2 import Trash2
from .circle_user import CircleUser
from .skip_back import SkipBack
from .file_plus import FilePlus
from .scroll_text import ScrollText
from .diamond import Diamond
from .delete import Delete
from .command import Command
from .package_check import PackageCheck
from .align_center_horizontal import AlignCenterHorizontal
from .clock import Clock
from .bell_ring import BellRing
from .remove_formatting import RemoveFormatting
from .router import Router
from .footprints import Footprints
from .octagon import Octagon
from .arrow_big_left import ArrowBigLeft
from .table_rows_split import TableRowsSplit
from .phone import Phone
from .circle_x import CircleX
from .land_plot import LandPlot
from .align_horizontal_justify_center import AlignHorizontalJustifyCenter
from .sun_snow import SunSnow
from .chart_bar_increasing import ChartBarIncreasing
from .image_off import ImageOff
from .clock_alert import ClockAlert
from .umbrella_off import UmbrellaOff
from .arrow_down_a_z import ArrowDownAZ
from .panel_left_open import PanelLeftOpen
from .brain_circuit import BrainCircuit
from .move_vertical import MoveVertical
from .users_round import UsersRound
from .salad import Salad
from .dumbbell import Dumbbell
from .tractor import Tractor
from .waves import Waves
from .folder_closed import FolderClosed
from .eye import Eye
from .user_round_cog import UserRoundCog
from .mouse_pointer_ban import MousePointerBan
from .drone import Drone
from .headphone_off import HeadphoneOff
from .badge_alert import BadgeAlert
from .server_cog import ServerCog
from .pipette import Pipette
from .phone_off import PhoneOff
from .flower import Flower
from .banknote import Banknote
from .ruler_dimension_line import RulerDimensionLine
from .sprout import Sprout
from .brick_wall import BrickWall
from .copy_check import CopyCheck
from .rectangle_vertical import RectangleVertical
from .pill import Pill
from .codepen import Codepen
from .dribbble import Dribbble
from .chart_bar_big import ChartBarBig
from .message_circle_plus import MessageCirclePlus
from .axe import Axe
from .square_plus import SquarePlus
from .gift import Gift
from .receipt_russian_ruble import ReceiptRussianRuble
from .package_plus import PackagePlus
from .external_link import ExternalLink
from .currency import Currency
from .wand import Wand
from .file_music import FileMusic
from .car import Car
from .zap import Zap
from .trello import Trello
from .list_checks import ListChecks
from .square_pause import SquarePause
from .message_square_reply import MessageSquareReply
from .badge_x import BadgeX
from .building_2 import Building2
from .list_chevrons_down_up import ListChevronsDownUp
from .chart_no_axes_gantt import ChartNoAxesGantt
from .moon_star import MoonStar
from .clock_1 import Clock1
from .cigarette_off import CigaretteOff
from .binary import Binary
from .chevron_last import ChevronLast
from .pointer_off import PointerOff
from .mouse_pointer_2 import MousePointer2
from .package_search import PackageSearch
from .mic_off import MicOff
from .lamp_desk import LampDesk
from .text_align_start import TextAlignStart
from .share import Share
from .circle_parking_off import CircleParkingOff
from .tags import Tags
from .square_bottom_dashed_scissors import SquareBottomDashedScissors
from .album import Album
from .key_round import KeyRound
from .square_code import SquareCode
from .folder_search_2 import FolderSearch2
from .arrow_up import ArrowUp
from .circle_arrow_out_up_left import CircleArrowOutUpLeft
from .wifi_high import WifiHigh
from .microscope import Microscope
from .test_tube import TestTube
from .bell_off import BellOff
from .linkedin import Linkedin
from .arrow_down_narrow_wide import ArrowDownNarrowWide
from .clock_3 import Clock3
from .panel_right import PanelRight
from .drum import Drum
from .view import View
from .music_2 import Music2
from .git_compare_arrows import GitCompareArrows
from .ev_charger import EvCharger
from .calendar_minus import CalendarMinus
from .book_image import BookImage
from .user_round_x import UserRoundX
from .undo import Undo
from .video import Video
from .circle_ellipsis import CircleEllipsis
from .id_card import IdCard
from .activity import Activity
from .pencil_line import PencilLine
from .square_stop import SquareStop
from .person_standing import PersonStanding
from .twitter import Twitter
from .map_pin import MapPin
from .folder_input import FolderInput
from .brush_cleaning import BrushCleaning
from .clock_arrow_up import ClockArrowUp
from .chess_pawn import ChessPawn
from .lightbulb_off import LightbulbOff
from .phone_incoming import PhoneIncoming
from .refrigerator import Refrigerator
from .italic import Italic
from .list_end import ListEnd
from .handshake import Handshake
from .map_pin_check import MapPinCheck
from .chevrons_left import ChevronsLeft
from .rows_2 import Rows2
from .mail_x import MailX
from .medal import Medal
from .message_circle_code import MessageCircleCode
from .calendar import Calendar
from .inspection_panel import InspectionPanel
from .notepad_text import NotepadText
from .message_circle_x import MessageCircleX
from .arrow_right_from_line import ArrowRightFromLine
from .tool_case import ToolCase
from .globe import Globe
from .arrow_left import ArrowLeft
from .paintbrush import Paintbrush
from .rows_3 import Rows3
from .badge_swiss_franc import BadgeSwissFranc
from .text_wrap import TextWrap
from .cross import Cross
from .square_minus import SquareMinus
from .university import University
from .route import Route
from .circle_arrow_up import CircleArrowUp
from .diameter import Diameter
from .pc_case import PcCase
from .ellipsis import Ellipsis
from .calendar_heart import CalendarHeart
from .book_headphones import BookHeadphones
from .microchip import Microchip
from .bottle_wine import BottleWine
from .arrow_down_right import ArrowDownRight
from .file_box import FileBox
from .paw_print import PawPrint
from .laptop import Laptop
from .power_off import PowerOff
from .redo_dot import RedoDot
from .axis_3d import Axis3d
from .chart_area import ChartArea
from .arrow_big_up import ArrowBigUp
from .framer import Framer
from .keyboard_off import KeyboardOff
from .map_plus import MapPlus
from .mountain import Mountain
from .stretch_horizontal import StretchHorizontal
from .bell_dot import BellDot
from .clipboard_x import ClipboardX
from .folder_down import FolderDown
from .panel_bottom_dashed import PanelBottomDashed
from .chess_queen import ChessQueen
from .volume_x import VolumeX
from .music_3 import Music3
from .copy_slash import CopySlash
from .file_code import FileCode
from .save_off import SaveOff
from .move_left import MoveLeft
from .slack import Slack
from .circle_dashed import CircleDashed
from .clock_2 import Clock2
from .user_round_minus import UserRoundMinus
from .scissors_line_dashed import ScissorsLineDashed
from .file_output import FileOutput
from .cloud import Cloud
from .hop_off import HopOff
from .clock_11 import Clock11
from .shuffle import Shuffle
from .quote import Quote
from .anvil import Anvil
from .washing_machine import WashingMachine
from .grip_vertical import GripVertical
from .clock_6 import Clock6
from .drill import Drill
from .file_braces import FileBraces
from .align_horizontal_distribute_start import AlignHorizontalDistributeStart
from .list_check import ListCheck
from .file_type import FileType
from .rewind import Rewind
from .wine_off import WineOff
from .circle_fading_arrow_up import CircleFadingArrowUp
from .upload import Upload
from .trending_down import TrendingDown
from .bookmark_check import BookmarkCheck
from .fold_vertical import FoldVertical
from .calendar_x import CalendarX
from .closed_caption import ClosedCaption
from .pause import Pause
from .radical import Radical
from .arrow_big_up_dash import ArrowBigUpDash
from .squircle_dashed import SquircleDashed
from .folder_key import FolderKey
from .grid_2x2 import Grid2x2
from .cloud_hail import CloudHail
from .search_x import SearchX
from .chromium import Chromium
from .cloudy import Cloudy
from .replace import Replace
from .forward import Forward
from .mountain_snow import MountainSnow
from .circle_minus import CircleMinus
from .dices import Dices
from .blend import Blend
from .bookmark import Bookmark
from .funnel_plus import FunnelPlus
from .file_exclamation_point import FileExclamationPoint
from .braces import Braces
from .rocket import Rocket
from .circle_dot import CircleDot
from .move_right import MoveRight
from .drama import Drama
from .asterisk import Asterisk
from .user_check import UserCheck
from .calendar_clock import CalendarClock
from .fish_off import FishOff
from .folder_search import FolderSearch
from .folder_pen import FolderPen
from .cloud_sun_rain import CloudSunRain
from .file_chart_pie import FileChartPie
from .git_pull_request_create import GitPullRequestCreate
from .tablet import Tablet
from .mail_check import MailCheck
from .align_vertical_justify_center import AlignVerticalJustifyCenter
from .file_diff import FileDiff
from .monitor_dot import MonitorDot
from .ticket_slash import TicketSlash
from .align_horizontal_space_between import AlignHorizontalSpaceBetween
from .webhook import Webhook
from .briefcase_conveyor_belt import BriefcaseConveyorBelt
from .diamond_percent import DiamondPercent
from .folder_open_dot import FolderOpenDot
from .arrow_left_right import ArrowLeftRight
from .code_xml import CodeXml
from .cloud_download import CloudDownload
from .utility_pole import UtilityPole
from .square_dashed import SquareDashed
from .signal_zero import SignalZero
from .squares_unite import SquaresUnite
from .book_up_2 import BookUp2
from .monitor_off import MonitorOff
from .ear import Ear
from .spell_check import SpellCheck
from .file_terminal import FileTerminal
from .flame import Flame
from .gallery_horizontal_end import GalleryHorizontalEnd
from .nut_off import NutOff
from .component import Component
from .wifi_cog import WifiCog
from .circle_off import CircleOff
from .align_start_horizontal import AlignStartHorizontal
from .locate_fixed import LocateFixed
from .lock_open import LockOpen
from .loader_pinwheel import LoaderPinwheel
from .atom import Atom
from .cat import Cat
from .file_check_corner import FileCheckCorner
from .cloud_cog import CloudCog
from .sword import Sword
from .square_pilcrow import SquarePilcrow
from .squirrel import Squirrel
from .menu import Menu
from .pin_off import PinOff
from .venus_and_mars import VenusAndMars
from .lamp_ceiling import LampCeiling
from .folder_dot import FolderDot
from .utensils_crossed import UtensilsCrossed
from .georgian_lari import GeorgianLari
from .ratio import Ratio
from .square_arrow_down_left import SquareArrowDownLeft
from .grid_2x2_x import Grid2x2X
from .octagon_alert import OctagonAlert
from .gallery_vertical import GalleryVertical
from .image_minus import ImageMinus
from .clock_7 import Clock7
from .arrow_right_to_line import ArrowRightToLine
from .a_arrow_down import AArrowDown
from .merge import Merge
from .map_pinned import MapPinned
from .square_pi import SquarePi
from .align_horizontal_space_around import AlignHorizontalSpaceAround
from .sticky_note import StickyNote
from .ticket_plus import TicketPlus
from .shopping_cart import ShoppingCart
from .copy_x import CopyX
from .calculator import Calculator
from .clock_10 import Clock10
from .train_front_tunnel import TrainFrontTunnel
from .clock_12 import Clock12
from .apple import Apple
from .circle_chevron_left import CircleChevronLeft
from .mouse import Mouse
from .flask_conical import FlaskConical
from .picture_in_picture_2 import PictureInPicture2
from .pentagon import Pentagon
from .diamond_minus import DiamondMinus
from .waves_ladder import WavesLadder
from .shield_check import ShieldCheck
from .arrow_down_0_1 import ArrowDown01
from .message_circle_reply import MessageCircleReply
from .circle_pause import CirclePause
from .mails import Mails
from .clock_5 import Clock5
from .chess_bishop import ChessBishop
from .rectangle_horizontal import RectangleHorizontal
from .shopping_basket import ShoppingBasket
from .list_filter import ListFilter
from .receipt_text import ReceiptText
from .music_4 import Music4
from .book_user import BookUser
from .shield_ban import ShieldBan
from .arrow_down_to_dot import ArrowDownToDot
from .building import Building
from .clipboard_copy import ClipboardCopy
from .binoculars import Binoculars
from .angry import Angry
from .lollipop import Lollipop
from .between_vertical_end import BetweenVerticalEnd
from .history import History
from .gavel import Gavel
from .folder import Folder
from .drafting_compass import DraftingCompass
from .align_horizontal_distribute_center import AlignHorizontalDistributeCenter
from .file_lock import FileLock
from .layers_2 import Layers2
from .users import Users
from .chart_column_stacked import ChartColumnStacked
from .boom_box import BoomBox
from .slice import Slice
from .folder_git import FolderGit
from .flag_off import FlagOff
from .mic_vocal import MicVocal
from .heart_minus import HeartMinus
from .corner_down_left import CornerDownLeft
from .file_axis_3d import FileAxis3d
from .book_open_text import BookOpenText
from .timer import Timer
from .gamepad import Gamepad
from .git_commit_horizontal import GitCommitHorizontal
from .monitor import Monitor
from .clipboard_check import ClipboardCheck
from .unlink_2 import Unlink2
from .square_arrow_out_down_right import SquareArrowOutDownRight
from .minus import Minus
from .heart_pulse import HeartPulse
from .rows_4 import Rows4
from .heart_handshake import HeartHandshake
from .birdhouse import Birdhouse
from .bed_double import BedDouble
from .gamepad_directional import GamepadDirectional
from .text_search import TextSearch
from .audio_waveform import AudioWaveform
from .navigation_2 import Navigation2
from .paint_bucket import PaintBucket
from .panel_left_right_dashed import PanelLeftRightDashed
from .chevron_left import ChevronLeft
from .move_up import MoveUp
from .film import Film
from .moon import Moon
from .square_arrow_left import SquareArrowLeft
from .panel_bottom_close import PanelBottomClose
from .weight import Weight
from .shield_off import ShieldOff
from .scaling import Scaling
from .cable import Cable
from .accessibility import Accessibility
from .move_up_right import MoveUpRight
from .wallet_cards import WalletCards
from .calendar_sync import CalendarSync
from .bus_front import BusFront
from .lamp_wall_down import LampWallDown
from .mouse_pointer import MousePointer
from .train_front import TrainFront
from .calendar_minus_2 import CalendarMinus2
from .ribbon import Ribbon
from .square_stack import SquareStack
from .flip_horizontal import FlipHorizontal
from .map_pin_check_inside import MapPinCheckInside
from .gallery_horizontal import GalleryHorizontal
from .notebook import Notebook
from .stamp import Stamp
from .square_split_horizontal import SquareSplitHorizontal
from .text_initial import TextInitial
from .arrow_up_down import ArrowUpDown
from .screen_share import ScreenShare
from .calendar_days import CalendarDays
from .separator_horizontal import SeparatorHorizontal
from .ferris_wheel import FerrisWheel
from .sofa import Sofa
from .clock_4 import Clock4
from .ticket_check import TicketCheck
from .cherry import Cherry
from .fingerprint_pattern import FingerprintPattern
from .heart import Heart
from .trending_up import TrendingUp




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FlagTriangleLeft(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-flag-triangle-left'], 'items': [{'path': {'d': 'M18 22V2.8a.8.8 0 0 0-1.17-.71L5.45 7.78a.8.8 0 0 0 0 1.44L18 15.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TurkishLira(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-turkish-lira'], 'items': [{'path': {'d': 'M15 4 5 9'}}, {'path': {'d': 'm15 8.5-10 5'}}, {'path': {'d': 'M18 12a9 9 0 0 1-9 9V3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Venus(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-venus'], 'items': [{'path': {'d': 'M12 15v7'}}, {'path': {'d': 'M9 19h6'}}, {'circle': {'cx': '12', 'cy': '9', 'r': '6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Ear(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-ear'], 'items': [{'path': {'d': 'M6 8.5a6.5 6.5 0 1 1 13 0c0 6-6 6-6 10a3.5 3.5 0 1 1-7 0'}}, {'path': {'d': 'M15 8.5a2.5 2.5 0 0 0-5 0v1a2 2 0 1 1 0 4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def RussianRuble(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-russian-ruble'], 'items': [{'path': {'d': 'M6 11h8a4 4 0 0 0 0-8H9v18'}}, {'path': {'d': 'M6 15h8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BookmarkX(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bookmark-x'], 'items': [{'path': {'d': 'm19 21-7-4-7 4V5a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2Z'}}, {'path': {'d': 'm14.5 7.5-5 5'}}, {'path': {'d': 'm9.5 7.5 5 5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Plane(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-plane'], 'items': [{'path': {'d': 'M17.8 19.2 16 11l3.5-3.5C21 6 21.5 4 21 3c-1-.5-3 0-4.5 1.5L13 8 4.8 6.2c-.5-.1-.9.1-1.1.5l-.3.5c-.2.5-.1 1 .3 1.3L9 12l-2 3H4l-1 1 3 2 2 3 1-1v-3l3-2 3.5 5.3c.3.4.8.5 1.3.3l.5-.2c.4-.3.6-.7.5-1.2z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TrainFrontTunnel(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-train-front-tunnel'], 'items': [{'path': {'d': 'M2 22V12a10 10 0 1 1 20 0v10'}}, {'path': {'d': 'M15 6.8v1.4a3 2.8 0 1 1-6 0V6.8'}}, {'path': {'d': 'M10 15h.01'}}, {'path': {'d': 'M14 15h.01'}}, {'path': {'d': 'M10 19a4 4 0 0 1-4-4v-3a6 6 0 1 1 12 0v3a4 4 0 0 1-4 4Z'}}, {'path': {'d': 'm9 19-2 3'}}, {'path': {'d': 'm15 19 2 3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def HardHat(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-hard-hat'], 'items': [{'path': {'d': 'M10 10V5a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v5'}}, {'path': {'d': 'M14 6a6 6 0 0 1 6 6v3'}}, {'path': {'d': 'M4 15v-3a6 6 0 0 1 6-6'}}, {'rect': {'x': '2', 'y': '15', 'width': '20', 'height': '4', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MessageSquareOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-message-square-off'], 'items': [{'path': {'d': 'M19 19H6.828a2 2 0 0 0-1.414.586l-2.202 2.202A.7.7 0 0 1 2 21.286V5a2 2 0 0 1 1.184-1.826'}}, {'path': {'d': 'm2 2 20 20'}}, {'path': {'d': 'M8.656 3H20a2 2 0 0 1 2 2v11.344'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SunDim(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-sun-dim'], 'items': [{'circle': {'cx': '12', 'cy': '12', 'r': '4'}}, {'path': {'d': 'M12 4h.01'}}, {'path': {'d': 'M20 12h.01'}}, {'path': {'d': 'M12 20h.01'}}, {'path': {'d': 'M4 12h.01'}}, {'path': {'d': 'M17.657 6.343h.01'}}, {'path': {'d': 'M17.657 17.657h.01'}}, {'path': {'d': 'M6.343 17.657h.01'}}, {'path': {'d': 'M6.343 6.343h.01'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Expand(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-expand'], 'items': [{'path': {'d': 'm15 15 6 6'}}, {'path': {'d': 'm15 9 6-6'}}, {'path': {'d': 'M21 16v5h-5'}}, {'path': {'d': 'M21 8V3h-5'}}, {'path': {'d': 'M3 16v5h5'}}, {'path': {'d': 'm3 21 6-6'}}, {'path': {'d': 'M3 8V3h5'}}, {'path': {'d': 'M9 9 3 3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Camera(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-camera'], 'items': [{'path': {'d': 'M13.997 4a2 2 0 0 1 1.76 1.05l.486.9A2 2 0 0 0 18.003 7H20a2 2 0 0 1 2 2v9a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V9a2 2 0 0 1 2-2h1.997a2 2 0 0 0 1.759-1.048l.489-.904A2 2 0 0 1 10.004 4z'}}, {'circle': {'cx': '12', 'cy': '13', 'r': '3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Euro(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-euro'], 'items': [{'path': {'d': 'M4 10h12'}}, {'path': {'d': 'M4 14h9'}}, {'path': {'d': 'M19 6a7.7 7.7 0 0 0-5.2-2A7.9 7.9 0 0 0 6 12c0 4.4 3.5 8 7.8 8 2 0 3.8-.8 5.2-2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TestTube(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-test-tube'], 'items': [{'path': {'d': 'M14.5 2v17.5c0 1.4-1.1 2.5-2.5 2.5c-1.4 0-2.5-1.1-2.5-2.5V2'}}, {'path': {'d': 'M8.5 2h7'}}, {'path': {'d': 'M14.5 16h-5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def VibrateOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-vibrate-off'], 'items': [{'path': {'d': 'm2 8 2 2-2 2 2 2-2 2'}}, {'path': {'d': 'm22 8-2 2 2 2-2 2 2 2'}}, {'path': {'d': 'M8 8v10c0 .55.45 1 1 1h6c.55 0 1-.45 1-1v-2'}}, {'path': {'d': 'M16 10.34V6c0-.55-.45-1-1-1h-4.34'}}, {'line': {'x1': '2', 'x2': '22', 'y1': '2', 'y2': '22'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Siren(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-siren'], 'items': [{'path': {'d': 'M7 18v-6a5 5 0 1 1 10 0v6'}}, {'path': {'d': 'M5 21a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-1a2 2 0 0 0-2-2H7a2 2 0 0 0-2 2z'}}, {'path': {'d': 'M21 12h1'}}, {'path': {'d': 'M18.5 4.5 18 5'}}, {'path': {'d': 'M2 12h1'}}, {'path': {'d': 'M12 2v1'}}, {'path': {'d': 'm4.929 4.929.707.707'}}, {'path': {'d': 'M12 12v6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ArrowDownZA(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-arrow-down-z-a'], 'items': [{'path': {'d': 'm3 16 4 4 4-4'}}, {'path': {'d': 'M7 4v16'}}, {'path': {'d': 'M15 4h5l-5 6h5'}}, {'path': {'d': 'M15 20v-3.5a2.5 2.5 0 0 1 5 0V20'}}, {'path': {'d': 'M20 18h-5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ServerCrash(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-server-crash'], 'items': [{'path': {'d': 'M6 10H4a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v4a2 2 0 0 1-2 2h-2'}}, {'path': {'d': 'M6 14H4a2 2 0 0 0-2 2v4a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-4a2 2 0 0 0-2-2h-2'}}, {'path': {'d': 'M6 6h.01'}}, {'path': {'d': 'M6 18h.01'}}, {'path': {'d': 'm13 6-4 6h6l-4 6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Lightbulb(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-lightbulb'], 'items': [{'path': {'d': 'M15 14c.2-1 .7-1.7 1.5-2.5 1-.9 1.5-2.2 1.5-3.5A6 6 0 0 0 6 8c0 1 .2 2.2 1.5 3.5.7.7 1.3 1.5 1.5 2.5'}}, {'path': {'d': 'M9 18h6'}}, {'path': {'d': 'M10 22h4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SendToBack(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-send-to-back'], 'items': [{'rect': {'x': '14', 'y': '14', 'width': '8', 'height': '8', 'rx': '2'}}, {'rect': {'x': '2', 'y': '2', 'width': '8', 'height': '8', 'rx': '2'}}, {'path': {'d': 'M7 14v1a2 2 0 0 0 2 2h1'}}, {'path': {'d': 'M14 7h1a2 2 0 0 1 2 2v1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def StarOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-star-off'], 'items': [{'path': {'d': 'M8.34 8.34 2 9.27l5 4.87L5.82 21 12 17.77 18.18 21l-.59-3.43'}}, {'path': {'d': 'M18.42 12.76 22 9.27l-6.91-1L12 2l-1.44 2.91'}}, {'line': {'x1': '2', 'x2': '22', 'y1': '2', 'y2': '22'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PinOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-pin-off'], 'items': [{'path': {'d': 'M12 17v5'}}, {'path': {'d': 'M15 9.34V7a1 1 0 0 1 1-1 2 2 0 0 0 0-4H7.89'}}, {'path': {'d': 'm2 2 20 20'}}, {'path': {'d': 'M9 9v1.76a2 2 0 0 1-1.11 1.79l-1.78.9A2 2 0 0 0 5 15.24V16a1 1 0 0 0 1 1h11'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Bath(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bath'], 'items': [{'path': {'d': 'M10 4 8 6'}}, {'path': {'d': 'M17 19v2'}}, {'path': {'d': 'M2 12h20'}}, {'path': {'d': 'M7 19v2'}}, {'path': {'d': 'M9 5 7.621 3.621A2.121 2.121 0 0 0 4 5v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def View(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-view'], 'items': [{'path': {'d': 'M21 17v2a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-2'}}, {'path': {'d': 'M21 7V5a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v2'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '1'}}, {'path': {'d': 'M18.944 12.33a1 1 0 0 0 0-.66 7.5 7.5 0 0 0-13.888 0 1 1 0 0 0 0 .66 7.5 7.5 0 0 0 13.888 0'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TextQuote(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-text-quote'], 'items': [{'path': {'d': 'M17 5H3'}}, {'path': {'d': 'M21 12H8'}}, {'path': {'d': 'M21 19H8'}}, {'path': {'d': 'M3 12v7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Shrink(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-shrink'], 'items': [{'path': {'d': 'm15 15 6 6m-6-6v4.8m0-4.8h4.8'}}, {'path': {'d': 'M9 19.8V15m0 0H4.2M9 15l-6 6'}}, {'path': {'d': 'M15 4.2V9m0 0h4.8M15 9l6-6'}}, {'path': {'d': 'M9 4.2V9m0 0H4.2M9 9 3 3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TextInitial(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-text-initial'], 'items': [{'path': {'d': 'M15 5h6'}}, {'path': {'d': 'M15 12h6'}}, {'path': {'d': 'M3 19h18'}}, {'path': {'d': 'm3 12 3.553-7.724a.5.5 0 0 1 .894 0L11 12'}}, {'path': {'d': 'M3.92 10h6.16'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Linkedin(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-linkedin'], 'items': [{'path': {'d': 'M16 8a6 6 0 0 1 6 6v7h-4v-7a2 2 0 0 0-2-2 2 2 0 0 0-2 2v7h-4v-7a6 6 0 0 1 6-6z'}}, {'rect': {'width': '4', 'height': '12', 'x': '2', 'y': '9'}}, {'circle': {'cx': '4', 'cy': '4', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def AlarmClockOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-alarm-clock-off'], 'items': [{'path': {'d': 'M6.87 6.87a8 8 0 1 0 11.26 11.26'}}, {'path': {'d': 'M19.9 14.25a8 8 0 0 0-9.15-9.15'}}, {'path': {'d': 'm22 6-3-3'}}, {'path': {'d': 'M6.26 18.67 4 21'}}, {'path': {'d': 'm2 2 20 20'}}, {'path': {'d': 'M4 4 2 6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Tornado(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-tornado'], 'items': [{'path': {'d': 'M21 4H3'}}, {'path': {'d': 'M18 8H6'}}, {'path': {'d': 'M19 12H9'}}, {'path': {'d': 'M16 16h-6'}}, {'path': {'d': 'M11 20H9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ChevronsLeftRightEllipsis(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chevrons-left-right-ellipsis'], 'items': [{'path': {'d': 'M12 12h.01'}}, {'path': {'d': 'M16 12h.01'}}, {'path': {'d': 'm17 7 5 5-5 5'}}, {'path': {'d': 'm7 7-5 5 5 5'}}, {'path': {'d': 'M8 12h.01'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def HdmiPort(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-hdmi-port'], 'items': [{'path': {'d': 'M22 9a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v4a1 1 0 0 0 1 1h1l2 2h12l2-2h1a1 1 0 0 0 1-1Z'}}, {'path': {'d': 'M7.5 12h9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BookUser(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-book-user'], 'items': [{'path': {'d': 'M15 13a3 3 0 1 0-6 0'}}, {'path': {'d': 'M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H19a1 1 0 0 1 1 1v18a1 1 0 0 1-1 1H6.5a1 1 0 0 1 0-5H20'}}, {'circle': {'cx': '12', 'cy': '8', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Goal(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-goal'], 'items': [{'path': {'d': 'M12 13V2l8 4-8 4'}}, {'path': {'d': 'M20.561 10.222a9 9 0 1 1-12.55-5.29'}}, {'path': {'d': 'M8.002 9.997a5 5 0 1 0 8.9 2.02'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BoomBox(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-boom-box'], 'items': [{'path': {'d': 'M4 9V5a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v4'}}, {'path': {'d': 'M8 8v1'}}, {'path': {'d': 'M12 8v1'}}, {'path': {'d': 'M16 8v1'}}, {'rect': {'width': '20', 'height': '12', 'x': '2', 'y': '9', 'rx': '2'}}, {'circle': {'cx': '8', 'cy': '15', 'r': '2'}}, {'circle': {'cx': '16', 'cy': '15', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Film(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-film'], 'items': [{'rect': {'width': '18', 'height': '18', 'x': '3', 'y': '3', 'rx': '2'}}, {'path': {'d': 'M7 3v18'}}, {'path': {'d': 'M3 7.5h4'}}, {'path': {'d': 'M3 12h18'}}, {'path': {'d': 'M3 16.5h4'}}, {'path': {'d': 'M17 3v18'}}, {'path': {'d': 'M17 7.5h4'}}, {'path': {'d': 'M17 16.5h4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def RectangleGoggles(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-rectangle-goggles'], 'items': [{'path': {'d': 'M20 6a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2h-4a2 2 0 0 1-1.6-.8l-1.6-2.13a1 1 0 0 0-1.6 0L9.6 17.2A2 2 0 0 1 8 18H4a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
